@@ -17,7 +17,8 @@ from napoleontoolbox.forecasting import lgbm_model_wrapper
 from napoleontoolbox.forecasting import xgb_model_wrapper
 from napoleontoolbox.forecasting import standard_mean_model_wrapper
 from napoleontoolbox.forecasting import deterministic_sharpe_optim_model_wrapper
-from napoleontoolbox.forecasting import  to_weighted_mean_model_wrapper
+from napoleontoolbox.forecasting import to_weighted_mean_model_wrapper
+from napoleontoolbox.forecasting import max_occurence_model_wrapper
 
 from abc import ABC, abstractmethod
 
@@ -26,7 +27,7 @@ def instantiate_model(method):
     if method == 'standard':
         return linear_model_wrapper.LinearModel()
     if method == 'lasso':
-        return lasso_model_wrapper.LASSOModel()
+        return lasso_model_wrapper.LassoModel
 #        alpha = 0.1
 #        self.model = Lasso(alpha=alpha, fit_intercept=False, max_iter=5000)
     if method == 'lgbm':
@@ -39,6 +40,8 @@ def instantiate_model(method):
         return to_weighted_mean_model_wrapper.WeightedMeanModel()
     if method == 'deterministic_sharpe_optim':
         return deterministic_sharpe_optim_model_wrapper.DeterministicSharpeOptimModel()
+    if method == 'max_occurence':
+        return max_occurence_model_wrapper.MaxOccurenceModel()
 
 
 
