@@ -12,6 +12,7 @@ import json
 
 from napoleontoolbox.parallel_run import signal_result_analyzer
 
+from functools import partial
 
 
 def unjsonize_list_run_results(local_root_directory, list_pkl_file_name):
@@ -79,6 +80,31 @@ def roll(df, w):
     })
     return rolled_df.groupby(level=0)
 
+def f_sharpe_signals_optim_mix(signal_data, returns, w, display_threshold = 0.99, period = 252, initial_price = 1. , average_execution_cost = 7.5e-4 , transaction_cost = True, print_turnover = False):
+    N_ = signal_data.shape[1]
+    w = w.reshape([1,N_])
+    data = pd.DataFrame(signal_data.values * w, columns=signal_data.columns, index=signal_data.index)
+    data['signal'] = data.sum(axis=1)
+    data['turn_over'] = abs(data['signal'] - data['signal'].shift(-1).fillna(0.))
+    average_turn_over = data['turn_over'].sum() / len(data)
+    if print_turnover:
+        print('average freqly turn over')
+        print(average_turn_over)
+    data['close_return'] = returns.values
+    data['reconstituted_close'] = metrics.from_ret_to_price(data['close_return'],initial_price=initial_price)
+    data['non_adjusted_perf_return'] = data['close_return'] * data['signal']
+    if transaction_cost :
+        data['perf_return'] = data['non_adjusted_perf_return']- data['turn_over']*average_execution_cost
+    else :
+        data['perf_return'] = data['non_adjusted_perf_return']
+    data['reconstituted_perf'] = metrics.from_ret_to_price(data['perf_return'],initial_price=initial_price)
+    sharpe_strat = metrics.sharpe(data['perf_return'].dropna(), period= period, from_ret=True)
+    if np.random.rand()>display_threshold:
+        print(w)
+        print('signals mix sharpe')
+        print(sharpe_strat)
+    return -sharpe_strat
+
 def f_sharpe_signals_mix(data, w, display_threshold = 0.99, period = 252):
     all_signals = [col for col in data.columns if 'signal' in col]
     N_ = len(all_signals)
@@ -234,6 +260,37 @@ def reconstitute_prediction_perf(y_pred=None, y_true=None, initial_price = 1. ,
 def compute_turn_over(data=None):
     return abs((data.signal - data.signal.shift(-1).fillna(0.))).mean()
 
+def deterministic_optim_sharpe(signal_data=None, returns=None, display_params = True):
+    T_ = signal_data.shape[0]
+    N_ = signal_data.shape[1]
+    w0 = np.ones([N_]) / N_
+
+    const_sum = LinearConstraint(np.ones([1, N_]), [1], [1])
+    up_bound = 1.
+    low_bound = 0.
+    up_bound_ = max(up_bound, 1 / N_)
+    low_bound_ = min(low_bound, 1 / N_)
+    const_ind = Bounds(low_bound_ * np.ones([N_]), up_bound_ * np.ones([N_]))
+
+    if display_params:
+        print(max(signal_data.index))
+        print(min(signal_data.index))
+        print(N_)
+        print(T_)
+       # def f_sharpe_signals_optim_mix(signal_data, returns, w, display_threshold=0.99, period=252, initial_price=1.,average_execution_cost=7.5e-4, transaction_cost=True, print_turnover=False):
+
+    #func_to_optimize = partial(signal_utility.f_sharpe_signals_optim_mix(signal_data, returns))
+    func_to_optimize = lambda x : signal_utility.f_sharpe_signals_optim_mix(signal_data, returns, x)
+    w__ = minimize(
+        func_to_optimize,
+        w0,
+        method='SLSQP',
+        constraints=[const_sum],
+        bounds=const_ind
+    ).x
+    print('optimal weights')
+    print(w__)
+    return w__
 
 def optimize_weights(data = None, starting_date = None, ending_date = None):
     #T = data.index.size
